@@ -36,6 +36,7 @@ require 'MeCab';
 
 AmConf = Hash.new();
 
+# __BEGIN_AM_CONF__
 # =====================================================================
 #
 AmConf['User'] = 'tac';
@@ -117,10 +118,20 @@ AmConf['LockFile'] = '/tmp/FEML_LOCK_FILE.%user%.txt';
 #
 AmConf['SpamThreshold'] = 0.95;
 
+# __END_AM_CONF__
+
 # ---------------------------------------------------------------------
 # ---------------------------------------------------------------------
 #
-FemlVersion = 'feml-0.5.0';
+FemlVersion = 'feml-1.0.0';
+
+# =====================================================================
+# ե뤬ɤ߹ࡣ
+#
+begin
+	load "#{File::dirname(__FILE__)}/feml_config.rb";
+rescue LoadError
+end
 
 # =====================================================================
 # ֡뷿ܤˤĤơˤʤäƤ뤫ɤĴ٤롣
